module ExampleStuff exposing (Object, Person, Unit(..), correctPeople, decodedXml, fromXML, people, person, rebucket, stuff)

import Iso8601
import Time exposing (Month(..), Posix)
import Time.Extra
import Xml exposing (Value(..))
import Xml.Decode exposing (..)
import Xml.Encode exposing (null)
import Xml.Query exposing (..)


rebucket : a -> a
rebucket =
    identity


type Unit
    = Bytes Int


type alias Object =
    { time : Posix
    , size : Unit
    , path : List String
    }


defaultTime : Posix
defaultTime =
    Time.Extra.partsToPosix Time.utc <|
        Time.Extra.Parts 1970 Jan 1 0 0 0 0


iso8601ToTime : String -> Result String Posix
iso8601ToTime string =
    case Iso8601.toTime string of
        Ok res ->
            Ok res

        Err _ ->
            Err "Iso8601 parse error"


fromXML : String -> Result String (List Object)
fromXML body =
    let
        getObject : Value -> Result String Object
        getObject value =
            let
                time =
                    tag "LastModified" (string >> Result.andThen iso8601ToTime)
                        >> default defaultTime

                size =
                    tag "Size" (int >> Result.map (Bytes >> rebucket))
                        >> default (Bytes 0)

                path =
                    tag "Key" (string >> Result.map (String.split "/"))
                        >> default []
            in
            Result.map3
                (\tim siz pat ->
                    { time = tim
                    , size = siz
                    , path = pat
                    }
                )
                (time value)
                (size value)
                (path value)
    in
    decode body
        |> Result.map
            (tags "ListBucketResult"
                >> List.map (tags "Contents")
                >> List.concat
                >> collect getObject
            )


stuff =
    """
<?xml version="1.0" encoding="UTF-8"?>
<ListBucketResult xmlns="http://s3.amazonaws.com/doc/2006-03-01/"><Name>converge-builds-dl</Name><Prefix></Prefix><Marker></Marker><MaxKeys>1000</MaxKeys><IsTruncated>true</IsTruncated><Contents><Key>0.3.0-1-g9379a1d/converge_0.3.0-1-g9379a1d_darwin_386/converge</Key><LastModified>2016-10-27T16:09:19.000Z</LastModified><ETag>&quot;2f502a2524bef9b06cbb8aa8b820ad18&quot;</ETag><Size>10492296</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/converge_0.3.0-1-g9379a1d_darwin_386/converge.sha256sum</Key><LastModified>2016-10-27T16:09:20.000Z</LastModified><ETag>&quot;32910ed0031ec83fbf0550b6c48f717a&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/converge_0.3.0-1-g9379a1d_darwin_amd64/converge</Key><LastModified>2016-10-27T16:09:20.000Z</LastModified><ETag>&quot;07aa99ead2dcec8c9e123ed72dce9a67&quot;</ETag><Size>11777616</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/converge_0.3.0-1-g9379a1d_darwin_amd64/converge.sha256sum</Key><LastModified>2016-10-27T16:09:20.000Z</LastModified><ETag>&quot;d18a2d94741e3292ea1b7f2127b55346&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/converge_0.3.0-1-g9379a1d_freebsd_386/converge</Key><LastModified>2016-10-27T16:09:20.000Z</LastModified><ETag>&quot;c63cf7e6561955c66134a20bdaa8ddde&quot;</ETag><Size>9352416</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/converge_0.3.0-1-g9379a1d_freebsd_386/converge.sha256sum</Key><LastModified>2016-10-27T16:09:21.000Z</LastModified><ETag>&quot;6c96e5596ccdfe6df79a9688e0df08d7&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/converge_0.3.0-1-g9379a1d_freebsd_amd64/converge</Key><LastModified>2016-10-27T16:09:21.000Z</LastModified><ETag>&quot;d6d3f55ce301d779825b57aed3bc41b0&quot;</ETag><Size>10566080</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/converge_0.3.0-1-g9379a1d_freebsd_amd64/converge.sha256sum</Key><LastModified>2016-10-27T16:09:22.000Z</LastModified><ETag>&quot;f1c102a8b04a224e3467bcbf0914781d&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/converge_0.3.0-1-g9379a1d_freebsd_arm/converge</Key><LastModified>2016-10-27T16:09:22.000Z</LastModified><ETag>&quot;a9a3d26690977131435e4f8c2c2d45aa&quot;</ETag><Size>9601440</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/converge_0.3.0-1-g9379a1d_freebsd_arm/converge.sha256sum</Key><LastModified>2016-10-27T16:09:22.000Z</LastModified><ETag>&quot;b716b71839c873ea5e71a6829990f2fe&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/converge_0.3.0-1-g9379a1d_linux_386/converge</Key><LastModified>2016-10-27T16:09:22.000Z</LastModified><ETag>&quot;deb27084c77b91658e9b85d1394f5796&quot;</ETag><Size>9426368</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/converge_0.3.0-1-g9379a1d_linux_386/converge.sha256sum</Key><LastModified>2016-10-27T16:09:23.000Z</LastModified><ETag>&quot;0fa45e200bd8c71e3a2121dd30f6b829&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/converge_0.3.0-1-g9379a1d_linux_amd64/converge</Key><LastModified>2016-10-27T16:09:23.000Z</LastModified><ETag>&quot;0c0152f0729aeecb1faa008240bff33d&quot;</ETag><Size>10633440</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/converge_0.3.0-1-g9379a1d_linux_amd64/converge.sha256sum</Key><LastModified>2016-10-27T16:09:24.000Z</LastModified><ETag>&quot;8df41af2d6d0747eb0b8da0a5310fc47&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/converge_0.3.0-1-g9379a1d_linux_arm/converge</Key><LastModified>2016-10-27T16:09:24.000Z</LastModified><ETag>&quot;39d510baa0b5f856dd77140e5ae1ccfc&quot;</ETag><Size>9597736</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/converge_0.3.0-1-g9379a1d_linux_arm/converge.sha256sum</Key><LastModified>2016-10-27T16:09:24.000Z</LastModified><ETag>&quot;726efa5af99fb0473983814e63380723&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/converge_0.3.0-1-g9379a1d_linux_arm64/converge</Key><LastModified>2016-10-27T16:09:24.000Z</LastModified><ETag>&quot;f2e0cfb544a66cd8f48ae7b3c074cc45&quot;</ETag><Size>10827744</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/converge_0.3.0-1-g9379a1d_linux_arm64/converge.sha256sum</Key><LastModified>2016-10-27T16:09:24.000Z</LastModified><ETag>&quot;0e0aff1f31110860184a5bcf5a8a0a9e&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/converge_0.3.0-1-g9379a1d_linux_ppc64/converge</Key><LastModified>2016-10-27T16:09:25.000Z</LastModified><ETag>&quot;31aea8702f6f47fa5cb268a2a9fd4dab&quot;</ETag><Size>11155488</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/converge_0.3.0-1-g9379a1d_linux_ppc64/converge.sha256sum</Key><LastModified>2016-10-27T16:09:25.000Z</LastModified><ETag>&quot;077c1f3ba0f5c6f4ea8e0b1dfca8ca61&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/converge_0.3.0-1-g9379a1d_linux_ppc64le/converge</Key><LastModified>2016-10-27T16:09:25.000Z</LastModified><ETag>&quot;c6b1987199e5f62c7d814f5d2e52ba73&quot;</ETag><Size>11155488</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/converge_0.3.0-1-g9379a1d_linux_ppc64le/converge.sha256sum</Key><LastModified>2016-10-27T16:09:26.000Z</LastModified><ETag>&quot;5474f59ae9a685e6f3be50a9e9500411&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/converge_0.3.0-1-g9379a1d_solaris_amd64/converge</Key><LastModified>2016-10-27T16:09:26.000Z</LastModified><ETag>&quot;01cdddaad7cbeb749301d286d4e9f7f3&quot;</ETag><Size>10499648</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/converge_0.3.0-1-g9379a1d_solaris_amd64/converge.sha256sum</Key><LastModified>2016-10-27T16:09:26.000Z</LastModified><ETag>&quot;319a4dc07c7bbb25c61f0d621628498a&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/tgz/converge_0.3.0-1-g9379a1d_darwin_386.tar.gz</Key><LastModified>2016-10-27T16:09:26.000Z</LastModified><ETag>&quot;a38cfe66fbdd8603dd872feb3eafe7be&quot;</ETag><Size>3716435</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/tgz/converge_0.3.0-1-g9379a1d_darwin_amd64.tar.gz</Key><LastModified>2016-10-27T16:09:26.000Z</LastModified><ETag>&quot;76d52e519f9b2c386aad5181717a64c7&quot;</ETag><Size>3898734</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/tgz/converge_0.3.0-1-g9379a1d_freebsd_386.tar.gz</Key><LastModified>2016-10-27T16:09:27.000Z</LastModified><ETag>&quot;be20988fe985eaea650370d67b238616&quot;</ETag><Size>3523439</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/tgz/converge_0.3.0-1-g9379a1d_freebsd_amd64.tar.gz</Key><LastModified>2016-10-27T16:09:27.000Z</LastModified><ETag>&quot;dacbfc2e7f4d83cfda2f081d91535ade&quot;</ETag><Size>3705200</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/tgz/converge_0.3.0-1-g9379a1d_freebsd_arm.tar.gz</Key><LastModified>2016-10-27T16:09:28.000Z</LastModified><ETag>&quot;76c34b577d1a8d50947288e345094ce7&quot;</ETag><Size>3426884</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/tgz/converge_0.3.0-1-g9379a1d_linux_386.tar.gz</Key><LastModified>2016-10-27T16:09:28.000Z</LastModified><ETag>&quot;938558b74ad4b9f866daed89d5614882&quot;</ETag><Size>3528808</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/tgz/converge_0.3.0-1-g9379a1d_linux_amd64.tar.gz</Key><LastModified>2016-10-27T16:09:28.000Z</LastModified><ETag>&quot;cb5bbfb6dbf5abb428e946d17c63ceb0&quot;</ETag><Size>3734581</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/tgz/converge_0.3.0-1-g9379a1d_linux_arm.tar.gz</Key><LastModified>2016-10-27T16:09:28.000Z</LastModified><ETag>&quot;c7756f570cc11cf5c7041308620c9549&quot;</ETag><Size>3430170</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/tgz/converge_0.3.0-1-g9379a1d_linux_arm64.tar.gz</Key><LastModified>2016-10-27T16:09:28.000Z</LastModified><ETag>&quot;07f68d6811f72180169876c08f557ef8&quot;</ETag><Size>3453644</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/tgz/converge_0.3.0-1-g9379a1d_linux_ppc64.tar.gz</Key><LastModified>2016-10-27T16:09:29.000Z</LastModified><ETag>&quot;98ad62e802385a80789a0aae77c5d379&quot;</ETag><Size>3470101</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/tgz/converge_0.3.0-1-g9379a1d_linux_ppc64le.tar.gz</Key><LastModified>2016-10-27T16:09:30.000Z</LastModified><ETag>&quot;3497c881a376d7d18cd96afc7520a805&quot;</ETag><Size>3428050</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/tgz/converge_0.3.0-1-g9379a1d_solaris_amd64.tar.gz</Key><LastModified>2016-10-27T16:09:30.000Z</LastModified><ETag>&quot;0f2e32cf990f7d0c19408700d9d48ad6&quot;</ETag><Size>3678590</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-1-g9379a1d/tgz/tgz.sha256sum</Key><LastModified>2016-10-27T16:09:31.000Z</LastModified><ETag>&quot;ef3104e81c9ffc0dacec22191b46e5cc&quot;</ETag><Size>2102</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/converge_0.3.0-103-gf6db1a7_darwin_386/converge</Key><LastModified>2016-11-09T21:57:22.000Z</LastModified><ETag>&quot;7c93d9520bbf26b8721c75baa7b71331&quot;</ETag><Size>10647152</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/converge_0.3.0-103-gf6db1a7_darwin_386/converge.sha256sum</Key><LastModified>2016-11-09T21:57:23.000Z</LastModified><ETag>&quot;eb5757196388e92c1c3251dbbdcf4f67&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/converge_0.3.0-103-gf6db1a7_darwin_amd64/converge</Key><LastModified>2016-11-09T21:57:23.000Z</LastModified><ETag>&quot;726a6101c4021da14c1a374d2c433865&quot;</ETag><Size>11945840</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/converge_0.3.0-103-gf6db1a7_darwin_amd64/converge.sha256sum</Key><LastModified>2016-11-09T21:57:23.000Z</LastModified><ETag>&quot;f92f8a87ebabbd2591dea2e0d8a94f26&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/converge_0.3.0-103-gf6db1a7_freebsd_386/converge</Key><LastModified>2016-11-09T21:57:23.000Z</LastModified><ETag>&quot;7b8f3b77a2c1871e8a2c6c2b9f38e1bc&quot;</ETag><Size>9492256</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/converge_0.3.0-103-gf6db1a7_freebsd_386/converge.sha256sum</Key><LastModified>2016-11-09T21:57:24.000Z</LastModified><ETag>&quot;eeb7efda21e8b33b5319608e4a9938b8&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/converge_0.3.0-103-gf6db1a7_freebsd_amd64/converge</Key><LastModified>2016-11-09T21:57:24.000Z</LastModified><ETag>&quot;a1f96db829457feea0f48c32faf1fa63&quot;</ETag><Size>10718592</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/converge_0.3.0-103-gf6db1a7_freebsd_amd64/converge.sha256sum</Key><LastModified>2016-11-09T21:57:24.000Z</LastModified><ETag>&quot;2914397c1294bc7433dec44e479a2c6c&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/converge_0.3.0-103-gf6db1a7_freebsd_arm/converge</Key><LastModified>2016-11-09T21:57:24.000Z</LastModified><ETag>&quot;bc0d1a5c55df8f51d383e1fb617e31d7&quot;</ETag><Size>9737064</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/converge_0.3.0-103-gf6db1a7_freebsd_arm/converge.sha256sum</Key><LastModified>2016-11-09T21:57:24.000Z</LastModified><ETag>&quot;99a64c248f8da84f4e350ec744adebb5&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/converge_0.3.0-103-gf6db1a7_linux_386/converge</Key><LastModified>2016-11-09T21:57:24.000Z</LastModified><ETag>&quot;9ef10322112ade97d751757478e390f9&quot;</ETag><Size>9570304</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/converge_0.3.0-103-gf6db1a7_linux_386/converge.sha256sum</Key><LastModified>2016-11-09T21:57:25.000Z</LastModified><ETag>&quot;34c9ae88cfb176b886f5ac8292e74d96&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/converge_0.3.0-103-gf6db1a7_linux_amd64/converge</Key><LastModified>2016-11-09T21:57:25.000Z</LastModified><ETag>&quot;d2ff2782872a863220fea22c3b32b1b8&quot;</ETag><Size>10785760</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/converge_0.3.0-103-gf6db1a7_linux_amd64/converge.sha256sum</Key><LastModified>2016-11-09T21:57:26.000Z</LastModified><ETag>&quot;eac4f06338a4414d5d35d68b0e4129bb&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/converge_0.3.0-103-gf6db1a7_linux_arm/converge</Key><LastModified>2016-11-09T21:57:26.000Z</LastModified><ETag>&quot;9b8483351e404208955617cc4b9a06c4&quot;</ETag><Size>9729264</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/converge_0.3.0-103-gf6db1a7_linux_arm/converge.sha256sum</Key><LastModified>2016-11-09T21:57:27.000Z</LastModified><ETag>&quot;03a73b912dcb501eae419f0f3dd0d8ee&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/converge_0.3.0-103-gf6db1a7_linux_arm64/converge</Key><LastModified>2016-11-09T21:57:27.000Z</LastModified><ETag>&quot;4a84481670ed0dd7d71928f7daf9f06a&quot;</ETag><Size>10959808</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/converge_0.3.0-103-gf6db1a7_linux_arm64/converge.sha256sum</Key><LastModified>2016-11-09T21:57:27.000Z</LastModified><ETag>&quot;69a0b875fb7822a17f8f7a294a072300&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/converge_0.3.0-103-gf6db1a7_linux_ppc64/converge</Key><LastModified>2016-11-09T21:57:27.000Z</LastModified><ETag>&quot;631d58dbb6c271fbea2a75a7b5e940d8&quot;</ETag><Size>11287552</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/converge_0.3.0-103-gf6db1a7_linux_ppc64/converge.sha256sum</Key><LastModified>2016-11-09T21:57:29.000Z</LastModified><ETag>&quot;b7d1a240e62c8315f7f055949baf2ecc&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/converge_0.3.0-103-gf6db1a7_linux_ppc64le/converge</Key><LastModified>2016-11-09T21:57:29.000Z</LastModified><ETag>&quot;d94b2e8e6c339591f26fbfcaebc87db4&quot;</ETag><Size>11287520</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/converge_0.3.0-103-gf6db1a7_linux_ppc64le/converge.sha256sum</Key><LastModified>2016-11-09T21:57:29.000Z</LastModified><ETag>&quot;5120f376942777ce58fbf71e324b5c84&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/converge_0.3.0-103-gf6db1a7_solaris_amd64/converge</Key><LastModified>2016-11-09T21:57:30.000Z</LastModified><ETag>&quot;c9dd0c5dcd420dce338be3f71d2d61e5&quot;</ETag><Size>10648064</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/converge_0.3.0-103-gf6db1a7_solaris_amd64/converge.sha256sum</Key><LastModified>2016-11-09T21:57:30.000Z</LastModified><ETag>&quot;210c36ad2abf252ce3b10aefab07e321&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/tgz/converge_0.3.0-103-gf6db1a7_darwin_386.tar.gz</Key><LastModified>2016-11-09T21:57:30.000Z</LastModified><ETag>&quot;5580db14e35ef493e0d9654362ef394d&quot;</ETag><Size>3762645</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/tgz/converge_0.3.0-103-gf6db1a7_darwin_amd64.tar.gz</Key><LastModified>2016-11-09T21:57:30.000Z</LastModified><ETag>&quot;f94ebfbd9c668b2b8b07b7cf927da5ad&quot;</ETag><Size>3945600</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/tgz/converge_0.3.0-103-gf6db1a7_freebsd_386.tar.gz</Key><LastModified>2016-11-09T21:57:30.000Z</LastModified><ETag>&quot;d7b216bb873e793982c9f2ce937f44a8&quot;</ETag><Size>3566014</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/tgz/converge_0.3.0-103-gf6db1a7_freebsd_amd64.tar.gz</Key><LastModified>2016-11-09T21:57:30.000Z</LastModified><ETag>&quot;e26376a64b04ff2c79a6bef57c907cb8&quot;</ETag><Size>3751870</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/tgz/converge_0.3.0-103-gf6db1a7_freebsd_arm.tar.gz</Key><LastModified>2016-11-09T21:57:31.000Z</LastModified><ETag>&quot;a36e3b345c4e582c0c81f896159cb1a6&quot;</ETag><Size>3467821</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/tgz/converge_0.3.0-103-gf6db1a7_linux_386.tar.gz</Key><LastModified>2016-11-09T21:57:31.000Z</LastModified><ETag>&quot;b1fa9f53700a8a33f80c671b467d47b0&quot;</ETag><Size>3571104</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/tgz/converge_0.3.0-103-gf6db1a7_linux_amd64.tar.gz</Key><LastModified>2016-11-09T21:57:31.000Z</LastModified><ETag>&quot;80514de9e72494c0239c6de0d3112ffe&quot;</ETag><Size>3780287</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/tgz/converge_0.3.0-103-gf6db1a7_linux_arm.tar.gz</Key><LastModified>2016-11-09T21:57:31.000Z</LastModified><ETag>&quot;631843d6b7615af27e68477e99b9e084&quot;</ETag><Size>3470483</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/tgz/converge_0.3.0-103-gf6db1a7_linux_arm64.tar.gz</Key><LastModified>2016-11-09T21:57:31.000Z</LastModified><ETag>&quot;b3f5fd48ede73314760c5477518edd93&quot;</ETag><Size>3498614</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/tgz/converge_0.3.0-103-gf6db1a7_linux_ppc64.tar.gz</Key><LastModified>2016-11-09T21:57:31.000Z</LastModified><ETag>&quot;57b6d1481018225a594121f62a898bd0&quot;</ETag><Size>3512692</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/tgz/converge_0.3.0-103-gf6db1a7_linux_ppc64le.tar.gz</Key><LastModified>2016-11-09T21:57:32.000Z</LastModified><ETag>&quot;96ce3a27ab802e70cbcc88b525dc7235&quot;</ETag><Size>3472162</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/tgz/converge_0.3.0-103-gf6db1a7_solaris_amd64.tar.gz</Key><LastModified>2016-11-09T21:57:32.000Z</LastModified><ETag>&quot;7e2442e2b6677a8bc976b330b51235aa&quot;</ETag><Size>3725582</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-103-gf6db1a7/tgz/tgz.sha256sum</Key><LastModified>2016-11-09T21:57:32.000Z</LastModified><ETag>&quot;2664bbb42a37ecea8fd6e52799a6a0d5&quot;</ETag><Size>2126</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-11-gaa79ad9/converge_0.3.0-11-gaa79ad9_darwin_386/converge</Key><LastModified>2016-10-31T14:58:23.000Z</LastModified><ETag>&quot;6424da9a7387f508af939357a56b094d&quot;</ETag><Size>10518956</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-11-gaa79ad9/converge_0.3.0-11-gaa79ad9_darwin_386/converge.sha256sum</Key><LastModified>2016-10-31T14:58:24.000Z</LastModified><ETag>&quot;d23ffe5eaeec4ef47c1e5fd14e6cbaf0&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-11-gaa79ad9/converge_0.3.0-11-gaa79ad9_darwin_amd64/converge</Key><LastModified>2016-10-31T14:58:25.000Z</LastModified><ETag>&quot;689f979874c2514dfd2b0fe47f415d0a&quot;</ETag><Size>11800288</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-11-gaa79ad9/converge_0.3.0-11-gaa79ad9_darwin_amd64/converge.sha256sum</Key><LastModified>2016-10-31T14:58:26.000Z</LastModified><ETag>&quot;9cd93043986dfddca81abfc8c4fe3500&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-11-gaa79ad9/converge_0.3.0-11-gaa79ad9_freebsd_386/converge</Key><LastModified>2016-10-31T14:58:26.000Z</LastModified><ETag>&quot;88342532ebf4dfca6102609eb13abc87&quot;</ETag><Size>9377056</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-11-gaa79ad9/converge_0.3.0-11-gaa79ad9_freebsd_386/converge.sha256sum</Key><LastModified>2016-10-31T14:58:27.000Z</LastModified><ETag>&quot;f442a8832e3e41742a37daf6bdb8d1d7&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-11-gaa79ad9/converge_0.3.0-11-gaa79ad9_freebsd_amd64/converge</Key><LastModified>2016-10-31T14:58:27.000Z</LastModified><ETag>&quot;d857108e98015ab7e14f51b39ef90984&quot;</ETag><Size>10590752</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-11-gaa79ad9/converge_0.3.0-11-gaa79ad9_freebsd_amd64/converge.sha256sum</Key><LastModified>2016-10-31T14:58:27.000Z</LastModified><ETag>&quot;858ca2fa627f3577e95712f862b2baf9&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-11-gaa79ad9/converge_0.3.0-11-gaa79ad9_freebsd_arm/converge</Key><LastModified>2016-10-31T14:58:28.000Z</LastModified><ETag>&quot;e32bd262c866812ad9f463165dbe85b0&quot;</ETag><Size>9626056</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-11-gaa79ad9/converge_0.3.0-11-gaa79ad9_freebsd_arm/converge.sha256sum</Key><LastModified>2016-10-31T14:58:28.000Z</LastModified><ETag>&quot;3e0a97220a9f8977817d3f497a565fde&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-11-gaa79ad9/converge_0.3.0-11-gaa79ad9_linux_386/converge</Key><LastModified>2016-10-31T14:58:28.000Z</LastModified><ETag>&quot;e0947e3c2b68a041cadb80b1cbb9d73b&quot;</ETag><Size>9455104</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-11-gaa79ad9/converge_0.3.0-11-gaa79ad9_linux_386/converge.sha256sum</Key><LastModified>2016-10-31T14:58:28.000Z</LastModified><ETag>&quot;bea1f4ae65b81737160c8ace320d3c2f&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-11-gaa79ad9/converge_0.3.0-11-gaa79ad9_linux_amd64/converge</Key><LastModified>2016-10-31T14:58:28.000Z</LastModified><ETag>&quot;49307ddfdc60beedc13e8f28d86ed0fe&quot;</ETag><Size>10660160</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-11-gaa79ad9/converge_0.3.0-11-gaa79ad9_linux_amd64/converge.sha256sum</Key><LastModified>2016-10-31T14:58:29.000Z</LastModified><ETag>&quot;97151c842261169574a45444ee53de5a&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-11-gaa79ad9/converge_0.3.0-11-gaa79ad9_linux_arm/converge</Key><LastModified>2016-10-31T14:58:29.000Z</LastModified><ETag>&quot;275f763885e99e2994ce535bb27918ab&quot;</ETag><Size>9622352</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-11-gaa79ad9/converge_0.3.0-11-gaa79ad9_linux_arm/converge.sha256sum</Key><LastModified>2016-10-31T14:58:29.000Z</LastModified><ETag>&quot;a99a385560949e5ed97712770d6b41a9&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-11-gaa79ad9/converge_0.3.0-11-gaa79ad9_linux_arm64/converge</Key><LastModified>2016-10-31T14:58:30.000Z</LastModified><ETag>&quot;8c3122a35ede6e0b272400ea3dcde467&quot;</ETag><Size>10827840</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-11-gaa79ad9/converge_0.3.0-11-gaa79ad9_linux_arm64/converge.sha256sum</Key><LastModified>2016-10-31T14:58:30.000Z</LastModified><ETag>&quot;a0d3cd01e73af6add8ad35ea5cae2766&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-11-gaa79ad9/converge_0.3.0-11-gaa79ad9_linux_ppc64/converge</Key><LastModified>2016-10-31T14:58:30.000Z</LastModified><ETag>&quot;dffc985c6a85e9ee8a530f55bb25e06b&quot;</ETag><Size>11155584</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-11-gaa79ad9/converge_0.3.0-11-gaa79ad9_linux_ppc64/converge.sha256sum</Key><LastModified>2016-10-31T14:58:31.000Z</LastModified><ETag>&quot;38c4ebb792f1ae9c291215524c7b1a53&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-11-gaa79ad9/converge_0.3.0-11-gaa79ad9_linux_ppc64le/converge</Key><LastModified>2016-10-31T14:58:31.000Z</LastModified><ETag>&quot;cf1eb35ccd7766ac396ab2443302a098&quot;</ETag><Size>11155584</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-11-gaa79ad9/converge_0.3.0-11-gaa79ad9_linux_ppc64le/converge.sha256sum</Key><LastModified>2016-10-31T14:58:32.000Z</LastModified><ETag>&quot;e84a0a9b0b7111d009c8360c8b2f56e7&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-11-gaa79ad9/converge_0.3.0-11-gaa79ad9_solaris_amd64/converge</Key><LastModified>2016-10-31T14:58:32.000Z</LastModified><ETag>&quot;26068bb9a1dd2e23d20a5376603c277e&quot;</ETag><Size>10520224</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-11-gaa79ad9/converge_0.3.0-11-gaa79ad9_solaris_amd64/converge.sha256sum</Key><LastModified>2016-10-31T14:58:32.000Z</LastModified><ETag>&quot;9276fa05dae0d004f40d8410b54a6488&quot;</ETag><Size>77</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-11-gaa79ad9/tgz/converge_0.3.0-11-gaa79ad9_darwin_386.tar.gz</Key><LastModified>2016-10-31T14:58:32.000Z</LastModified><ETag>&quot;750db585688a567a6dc8eab6069a5df1&quot;</ETag><Size>3725243</Size><StorageClass>STANDARD</StorageClass></Contents><Contents><Key>0.3.0-11-gaa79ad9/tgz/converge_0.3.0-11-gaa79ad9_darwin_amd64.tar.gz</Key><LastModified>2016-10-31T14:58:33.000Z</LastModified><ETag>&quot;6cb27dd66ebb1a12c0318dce8c67be69&quot;</ETag><Size>3907127</Size><StorageClass>STANDARD</StorageClass></Contents></ListBucketResult>
"""


decodedXml : Value
decodedXml =
    """
<person>
    <name>noah</name>
    <age max="100">50</age>
</person>
<person>
    <name>josh</name>
    <age max="100">57</age>
</person>
    """
        |> decode
        |> Result.toMaybe
        |> Maybe.withDefault null


type alias Person =
    { name : String
    , age : Int
    }


person : Value -> Result String Person
person value =
    Result.map2
        (\name age ->
            { name = name
            , age = age
            }
        )
        (tag "name" string value)
        (tag "age" int value)


people : List Person
people =
    tags "person" decodedXml
        |> collect person


correctPeople : List Person
correctPeople =
    [ { name = "noah", age = 50 }
    , { name = "josh", age = 57 }
    ]
